pub struct PgAuthMembers {
pub roleid: Str,
pub member: Str,
pub grantor: Str,
pub admin_option: bool,
pub inherit_option: bool,
pub set_option: bool,
}Expand description
The DDL-only contents of pg_auth_members
Fields
roleid: Stroid (references pg_authid.oid) ID of a role that has a member
member: Stroid (references pg_authid.oid) ID of a role that is a member of roleid
grantor: Stroid (references pg_authid.oid) ID of the role that granted this membership
admin_option: boolbool True if member can grant membership in roleid to others
inherit_option: boolbool True if the member automatically inherits the privileges of the granted role
set_option: boolbool True if the member can SET ROLE to the granted role