PgCollation

Struct PgCollation 

pub struct PgCollation {
    pub oid: Str,
    pub collname: Str,
    pub collnamespace: Str,
    pub collowner: Str,
    pub collprovider: PgCollationCollprovider,
    pub collisdeterministic: bool,
    pub collencoding: Option<Str>,
    pub collcollate: Option<Str>,
    pub collctype: Option<Str>,
    pub colllocale: Option<Str>,
    pub collicurules: Option<Str>,
    pub description: Option<Str>,
}
The DDL-only contents of pg_collation

Fields

oid: Str

oid Row identifier

collname: Str

name Collation name (unique per namespace and encoding)

collnamespace: Str

oid (references pg_namespace.oid) The OID of the namespace that contains this collation

collowner: Str

oid (references pg_authid.oid) Owner of the collation

collprovider: PgCollationCollprovider

char Provider of the collation: d = database default, b = builtin, c = libc, i = icu

collisdeterministic: bool

bool Is the collation deterministic?

collencoding: Option<Str>

int4 Encoding in which the collation is applicable, or -1 if it works for any encoding

collcollate: Option<Str>

text LC_COLLATE for this collation object. If the provider is not libc, collcollate is NULL and colllocale is used instead.

collctype: Option<Str>

text LC_CTYPE for this collation object. If the provider is not libc, collctype is NULL and colllocale is used instead.

colllocale: Option<Str>

text Collation provider locale name for this collation object. If the provider is libc, colllocale is NULL; collcollate and collctype are used instead.

collicurules: Option<Str>

text ICU collation rules for this collation object

description: Option<Str>

text The comment from pg_description