PgConstraint

Struct PgConstraint 

pub struct PgConstraint {
Show 26 fields pub conname: Str, pub connamespace: Str, pub contype: PgConstraintContype, pub condeferrable: bool, pub condeferred: bool, pub convalidated: bool, pub conrelid: Option<Str>, pub contypid: Option<Str>, pub conindid: Option<Str>, pub conparentid: Option<Str>, pub confrelid: Option<Str>, pub confupdtype: Option<PgConstraintConfupdtype>, pub confdeltype: Option<PgConstraintConfdeltype>, pub confmatchtype: Option<PgConstraintConfmatchtype>, pub conislocal: bool, pub coninhcount: u16, pub connoinherit: bool, pub conkey: Option<Vec<u16>>, pub confkey: Option<Vec<u16>>, pub conpfeqop: Option<Vec<Str>>, pub conppeqop: Option<Vec<Str>>, pub conffeqop: Option<Vec<Str>>, pub confdelsetcols: Option<Vec<u16>>, pub conexclop: Option<Vec<Str>>, pub conbin: Option<Str>, pub description: Option<Str>,
}
The DDL-only contents of pg_constraint

Fields

conname: Str

name Constraint name (not necessarily unique!)

connamespace: Str

oid (references pg_namespace.oid) The OID of the namespace that contains this constraint

contype: PgConstraintContype

char c = check constraint, f = foreign key constraint, n = not-null constraint (domains only), p = primary key constraint, u = unique constraint, t = constraint trigger, x = exclusion constraint

condeferrable: bool

bool Is the constraint deferrable?

condeferred: bool

bool Is the constraint deferred by default?

convalidated: bool

bool Has the constraint been validated? Currently, can be false only for foreign keys and CHECK constraints

conrelid: Option<Str>

oid (references pg_class.oid) The table this constraint is on; zero if not a table constraint

contypid: Option<Str>

oid (references pg_type.oid) The domain this constraint is on; zero if not a domain constraint

conindid: Option<Str>

oid (references pg_class.oid) The index supporting this constraint, if it’s a unique, primary key, foreign key, or exclusion constraint; else zero

conparentid: Option<Str>

oid (references pg_constraint.oid) The corresponding constraint of the parent partitioned table, if this is a constraint on a partition; else zero

confrelid: Option<Str>

oid (references pg_class.oid) If a foreign key, the referenced table; else zero

confupdtype: Option<PgConstraintConfupdtype>

char Foreign key update action code: a = no action, r = restrict, c = cascade, n = set null, d = set default

confdeltype: Option<PgConstraintConfdeltype>

char Foreign key deletion action code: a = no action, r = restrict, c = cascade, n = set null, d = set default

confmatchtype: Option<PgConstraintConfmatchtype>

char Foreign key match type: f = full, p = partial, s = simple

conislocal: bool

bool This constraint is defined locally for the relation. Note that a constraint can be locally defined and inherited simultaneously.

coninhcount: u16

int2 The number of direct inheritance ancestors this constraint has. A constraint with a nonzero number of ancestors cannot be dropped nor renamed.

connoinherit: bool

bool This constraint is defined locally for the relation. It is a non-inheritable constraint.

conkey: Option<Vec<u16>>

int2[] (references pg_attribute.attnum) If a table constraint (including foreign keys, but not constraint triggers), list of the constrained columns

confkey: Option<Vec<u16>>

int2[] (references pg_attribute.attnum) If a foreign key, list of the referenced columns

conpfeqop: Option<Vec<Str>>

oid[] (references pg_operator.oid) If a foreign key, list of the equality operators for PK = FK comparisons

conppeqop: Option<Vec<Str>>

oid[] (references pg_operator.oid) If a foreign key, list of the equality operators for PK = PK comparisons

conffeqop: Option<Vec<Str>>

oid[] (references pg_operator.oid) If a foreign key, list of the equality operators for FK = FK comparisons

confdelsetcols: Option<Vec<u16>>

int2[] (references pg_attribute.attnum) If a foreign key with a SET NULL or SET DEFAULT delete action, the columns that will be updated. If null, all of the referencing columns will be updated.

conexclop: Option<Vec<Str>>

oid[] (references pg_operator.oid) If an exclusion constraint, list of the per-column exclusion operators

conbin: Option<Str>

pg_node_tree If a check constraint, an internal representation of the expression. (It’s recommended to use pg_get_constraintdef() to extract the definition of a check constraint.)

description: Option<Str>

text The comment from pg_description