pub struct PgDbRoleSetting {
pub setdatabase: Option<()>,
pub setrole: Option<Str>,
pub setconfig: Option<Vec<Str>>,
}Expand description
The DDL-only contents of pg_db_role_setting
Fields
setdatabase: Option<()>oid (references pg_database.oid) The OID of the database the setting is applicable to, or zero if not database-specific
setrole: Option<Str>oid (references pg_authid.oid) The OID of the role the setting is applicable to, or zero if not role-specific
setconfig: Option<Vec<Str>>text[] Defaults for run-time configuration variables