pub struct PgEventTrigger {
pub evtname: Str,
pub evtevent: Str,
pub evtowner: Str,
pub evtfoid: Str,
pub evtenabled: PgEventTriggerEvtenabled,
pub evttags: Option<Vec<Str>>,
pub description: Option<Str>,
pub seclabel: Option<Str>,
pub seclabel_provider: Option<Str>,
}Expand description
The DDL-only contents of pg_event_trigger
Fields
evtname: Strname Trigger name (must be unique)
evtevent: Strname Identifies the event for which this trigger fires
evtowner: Stroid (references pg_authid.oid) Owner of the event trigger
evtfoid: Stroid (references pg_proc.oid) The function to be called
evtenabled: PgEventTriggerEvtenabledchar Controls in which session_replication_role modes the event trigger fires. O = trigger fires in “origin” and “local” modes, D = trigger is disabled, R = trigger fires in “replica” mode, A = trigger fires always.
text[] Command tags for which this trigger will fire. If NULL, the firing of this trigger is not restricted on the basis of the command tag.
description: Option<Str>text The comment from pg_description
seclabel: Option<Str>text The seclabel from pg_seclabel
seclabel_provider: Option<Str>text The provider from pg_seclabel