pub struct PgInherits {
pub inhrelid: Str,
pub inhparent: Str,
pub inhseqno: u32,
}Expand description
The DDL-only contents of pg_inherits
Fields
inhrelid: Stroid (references pg_class.oid) The OID of the child table or index
inhparent: Stroid (references pg_class.oid) The OID of the parent table or index
inhseqno: u32int4 If there is more than one direct parent for a child table (multiple inheritance), this number tells the order in which the inherited columns are to be arranged. The count starts at 1. Indexes cannot have multiple inheritance, since they can only inherit when using declarative partitioning.