pub struct PgOpclass {
pub opcmethod: Str,
pub opcname: Str,
pub opcnamespace: Str,
pub opcowner: Str,
pub opcfamily: Str,
pub opcintype: Str,
pub opcdefault: bool,
pub opckeytype: Option<Str>,
pub description: Option<Str>,
}Expand description
The DDL-only contents of pg_opclass
Fields
opcmethod: Stroid (references pg_am.oid) Index access method operator class is for
opcname: Strname Name of this operator class
opcnamespace: Stroid (references pg_namespace.oid) Namespace of this operator class
opcowner: Stroid (references pg_authid.oid) Owner of the operator class
opcfamily: Stroid (references pg_opfamily.oid) Operator family containing the operator class
opcintype: Stroid (references pg_type.oid) Data type that the operator class indexes
opcdefault: boolbool True if this operator class is the default for opcintype
opckeytype: Option<Str>oid (references pg_type.oid) Type of data stored in index, or zero if same as opcintype
description: Option<Str>text The comment from pg_description