pub struct PgRange {
pub rngtypid: Str,
pub rngsubtype: Str,
pub rngmultitypid: Str,
pub rngcollation: Option<Str>,
pub rngsubopc: Str,
pub rngcanonical: Option<Str>,
pub rngsubdiff: Option<Str>,
}Expand description
The DDL-only contents of pg_range
Fields
rngtypid: Stroid (references pg_type.oid) OID of the range type
rngsubtype: Stroid (references pg_type.oid) OID of the element type (subtype) of this range type
rngmultitypid: Stroid (references pg_type.oid) OID of the multirange type for this range type
rngcollation: Option<Str>oid (references pg_collation.oid) OID of the collation used for range comparisons, or zero if none
rngsubopc: Stroid (references pg_opclass.oid) OID of the subtype’s operator class used for range comparisons
rngcanonical: Option<Str>regproc (references pg_proc.oid) OID of the function to convert a range value into canonical form, or zero if none
rngsubdiff: Option<Str>regproc (references pg_proc.oid) OID of the function to return the difference between two element values as double precision, or zero if none