pub struct PgStatisticExt {
pub stxrelid: Str,
pub stxname: Str,
pub stxnamespace: Str,
pub stxowner: Str,
pub stxkeys: Vec<u16>,
pub stxstattarget: Option<u16>,
pub stxkind: Vec<PgStatisticExtStxkind>,
pub stxexprs: Option<Str>,
pub description: Option<Str>,
}Expand description
The DDL-only contents of pg_statistic_ext
Fields
stxrelid: Stroid (references pg_class.oid) Table containing the columns described by this object
stxname: Strname Name of the statistics object
stxnamespace: Stroid (references pg_namespace.oid) The OID of the namespace that contains this statistics object
stxowner: Stroid (references pg_authid.oid) Owner of the statistics object
stxkeys: Vec<u16>int2vector (references pg_attribute.attnum) An array of attribute numbers, indicating which table columns are covered by this statistics object; for example a value of 1 3 would mean that the first and the third table columns are covered
stxstattarget: Option<u16>int2 stxstattarget controls the level of detail of statistics accumulated for this statistics object by ANALYZE. A zero value indicates that no statistics should be collected. A null value says to use the maximum of the statistics targets of the referenced columns, if set, or the system default statistics target. Positive values of stxstattarget determine the target number of “most common values” to collect.
stxkind: Vec<PgStatisticExtStxkind>char[] An array containing codes for the enabled statistics kinds; valid values are: d for n-distinct statistics, f for functional dependency statistics, m for most common values (MCV) list statistics, and e for expression statistics
stxexprs: Option<Str>pg_node_tree Expression trees (in nodeToString() representation) for statistics object attributes that are not simple column references. This is a list with one element per expression. Null if all statistics object attributes are simple references.
description: Option<Str>text The comment from pg_description