PgTransform

Struct PgTransform 

pub struct PgTransform {
    pub trftype: Str,
    pub trflang: Str,
    pub trffromsql: Option<Str>,
    pub trftosql: Option<Str>,
}
The DDL-only contents of pg_transform

Fields

trftype: Str

oid (references pg_type.oid) OID of the data type this transform is for

trflang: Str

oid (references pg_language.oid) OID of the language this transform is for

trffromsql: Option<Str>

regproc (references pg_proc.oid) The OID of the function to use when converting the data type for input to the procedural language (e.g., function parameters). Zero is stored if the default behavior should be used.

trftosql: Option<Str>

regproc (references pg_proc.oid) The OID of the function to use when converting output from the procedural language (e.g., return values) to the data type. Zero is stored if the default behavior should be used.